==> pypcapkit-0.12.0.post2.tar.gz: pypcapkit-0.12.0.post2/pcapkit/_vendor/hip_types.py <==
# -*- coding: utf-8 -*-


import collections
import csv
import os
import re

import requests


###############
# Defaults
###############


ROOT, FILE = os.path.split(os.path.abspath(__file__))

LINE = lambda NAME, DOCS, FLAG, ENUM, MISS: ('''\
# -*- coding: utf-8 -*-


from aenum import IntEnum, extend_enum


class {}(IntEnum):
    """Enumeration class for {}."""
    _ignore_ = '{} _'
    {} = vars()

    # {}
    {}

    @staticmethod
    def get(key, default=-1):
        """Backport support for original codes."""
        if isinstance(key, int):
            return {}(key)
        if key not in {}._member_map_:
            extend_enum({}, key, default)
        return {}[key]

    @classmethod
    def _missing_(cls, value):
        """Lookup function used when value is not found."""
        if not ({}):
            raise ValueError('%r is not a valid %s' % (value, cls.__name__))
        {}
        super()._missing_(value)
''').format((NAME), (NAME), (NAME), (NAME), (DOCS), (ENUM), (NAME), (NAME), (NAME), (NAME), (FLAG), (MISS))


###############
# Macros
###############


NAME = 'PktType'
DOCS = 'HIP Packet Types'
FLAG = 'isinstance(value, int) and 0 <= value <= 127'
LINK = 'https://www.iana.org/assignments/hip-parameters/hip-parameters-1.csv'


###############
# Processors
###############


page = requests.get(LINK)
data = page.text.strip().split('\r\n')

reader = csv.reader(data)
header = next(reader)
record = collections.Counter(map(lambda item: item[1],
    filter(lambda item: len(item[0].split('-')) != 2, reader)))

def rename(name, code, *, original):
    if record[name] > 1:
        return ('{} [{}]').format((name), (code))
    return name

reader = csv.reader(data)
header = next(reader)

enum = list()
miss = list()
for item in reader:
    long = item[1]
    rfcs = item[2]

    if ' - ' in long:
        name, cmmt = long.split(' -')
    elif ' (' in long:
        cmmt, name = (" {}").format((long.strip(')'))).split(' (')
    else:
        name, cmmt = long, ''

    temp = list()
    for rfc in filter(None, re.split(r'\[|\]', rfcs)):
        if 'RFC' in rfc:
            temp.append(('[{} {}]').format((rfc[:3]), (rfc[3:])))
        else:
            temp.append(('[{}]').format((rfc)))
    desc = (" {}").format((''.join(temp))) if rfcs else ''

    try:
        code, _ = item[0], int(item[0])
        renm = rename(name, code, original=long)

        pres = ("{}[{!r}] = {}").format((NAME), (renm), (code)).ljust(76)
        sufs = ('#{}{}').format((desc), (cmmt)) if desc or cmmt else ''

        enum.append(('{}{}').format((pres), (sufs)))
    except ValueError:
        start, stop = item[0].split('-')

        miss.append(('if {} <= value <= {}:').format((start), (stop)))
        if desc or cmmt:
            miss.append(('    #{}{}').format((desc), (cmmt)))
        miss.append(("    extend_enum(cls, '{} [%d]' % value, value)").format((name)))
        miss.append('    return cls(value)')


###############
# Defaults
###############


ENUM = '\n    '.join(map(lambda s: s.rstrip(), enum))
MISS = '\n        '.join(map(lambda s: s.rstrip(), miss))
with open(os.path.join(ROOT, ('../_common/{}').format((FILE))), 'w') as file:
    file.write(LINE(NAME, DOCS, FLAG, ENUM, MISS))

==> pypcapkit-0.12.4.tar.gz: pypcapkit-0.12.4/pcapkit/_vendor/hip_types.py <==
# -*- coding: utf-8 -*-

import collections
import csv
import os
import re

import requests

###############
# Defaults
###############


ROOT, FILE = os.path.split(os.path.abspath(__file__))


def LINE(NAME, DOCS, FLAG, ENUM, MISS): return f'''\
# -*- coding: utf-8 -*-


from aenum import IntEnum, extend_enum


class {NAME}(IntEnum):
    """Enumeration class for {NAME}."""
    _ignore_ = '{NAME} _'
    {NAME} = vars()

    # {DOCS}
    {ENUM}

    @staticmethod
    def get(key, default=-1):
        """Backport support for original codes."""
        if isinstance(key, int):
            return {NAME}(key)
        if key not in {NAME}._member_map_:
            extend_enum({NAME}, key, default)
        return {NAME}[key]

    @classmethod
    def _missing_(cls, value):
        """Lookup function used when value is not found."""
        if not ({FLAG}):
            raise ValueError('%r is not a valid %s' % (value, cls.__name__))
        {MISS}
        super()._missing_(value)
'''


###############
# Macros
###############


NAME = 'PktType'
DOCS = 'HIP Packet Types'
FLAG = 'isinstance(value, int) and 0 <= value <= 127'
LINK = 'https://www.iana.org/assignments/hip-parameters/hip-parameters-1.csv'


###############
# Processors
###############


page = requests.get(LINK)
data = page.text.strip().split('\r\n')

reader = csv.reader(data)
header = next(reader)
record = collections.Counter(map(lambda item: item[1],
                                 filter(lambda item: len(item[0].split('-')) != 2, reader)))


def rename(name, code, *, original):
    if record[name] > 1:
        return f'{name} [{code}]'
    return name


reader = csv.reader(data)
header = next(reader)

enum = list()
miss = list()
for item in reader:
    long = item[1]
    rfcs = item[2]

    if ' - ' in long:
        name, cmmt = long.split(' -')
    elif ' (' in long:
        cmmt, name = f" {long.strip(')')}".split(' (')
    else:
        name, cmmt = long, ''

    temp = list()
    for rfc in filter(None, re.split(r'\[|\]', rfcs)):
        if 'RFC' in rfc:
            temp.append(f'[{rfc[:3]} {rfc[3:]}]')
        else:
            temp.append(f'[{rfc}]')
    desc = f" {''.join(temp)}" if rfcs else ''

    try:
        code, _ = item[0], int(item[0])
        renm = rename(name, code, original=long)

        pres = f"{NAME}[{renm!r}] = {code}".ljust(76)
        sufs = f'#{desc}{cmmt}' if desc or cmmt else ''

        enum.append(f'{pres}{sufs}')
    except ValueError:
        start, stop = item[0].split('-')

        miss.append(f'if {start} <= value <= {stop}:')
        if desc or cmmt:
            miss.append(f'    #{desc}{cmmt}')
        miss.append(f"    extend_enum(cls, '{name} [%d]' % value, value)")
        miss.append('    return cls(value)')


###############
# Defaults
###############


ENUM = '\n    '.join(map(lambda s: s.rstrip(), enum))
MISS = '\n        '.join(map(lambda s: s.rstrip(), miss))
with open(os.path.join(ROOT, f'../_common/{FILE}'), 'w') as file:
    file.write(LINE(NAME, DOCS, FLAG, ENUM, MISS))
